@@ -41,6 +41,8 @@ def get_emotions(self):
     sum_values = sum(em_frequencies.values())
     em_percent = {'fear': 0.0, 'anger': 0.0, 'anticipation': 0.0, 'trust': 0.0, 'surprise': 0.0, 'positive': 0.0,
                   'negative': 0.0, 'sadness': 0.0, 'disgust': 0.0, 'joy': 0.0}
+    if self.sent_flag == 1:
+        em_percent = {'fear': 0.0, 'anger': 0.0, 'anticipation': 0.0, 'trust': 0.0, 'surprise': 0.0, 'sadness': 0.0,'disgust': 0.0, 'joy': 0.0}
     for key in em_frequencies.keys():
         em_percent.update({key: float(em_frequencies[key]) / float(sum_values)})
     self.em_list = em_list
@@ -51,7 +53,7 @@ def get_emotions(self):
 
 class EmoTFIDF:
     """Lexicon source is (C) 2016 National Research Council Canada (NRC) and library is for research purposes only.  Source: http://sentiment.nrc.ca/lexicons-for-research/"""
-
+    sent_flag=0
     with urllib.request.urlopen("https://raw.githubusercontent.com/mmsa/EmoTFIDF/main/emotions_lex.json") as url:
         lexicon = json.loads(url.read().decode())
 
@@ -59,17 +61,27 @@ class EmoTFIDF:
         self.text = process_message(text)
         self.words = list(nltk.word_tokenize(self.text))
         self.sentences = list(nltk.sent_tokenize(self.text))
+        if self.sent_flag==1:
+            for key, val in self.lexicon.items():
+                if 'positive' in val:
+                    val.remove('positive')
+                if 'negative' in val:
+                    val.remove('negative')
         get_emotions(self)
 
-    def set_lexicon_path(self,path):
+    def set_lexicon_path(self, path):
         self.path = path
-        if path!=' ' and path!=0:
+        if path != ' ' and path != 0:
             with open(path) as jsonfile:
                 self.lexicon = json.load(jsonfile)
         else:
-            with urllib.request.urlopen("https://raw.githubusercontent.com/mmsa/EmoTFIDF/main/emotions_lex.json") as url:
+            with urllib.request.urlopen(
+                    "https://raw.githubusercontent.com/mmsa/EmoTFIDF/main/emotions_lex.json") as url:
                 self.lexicon = json.loads(url.read().decode())
 
+    def remove_sentiments(self, sent_flag):
+        self.sent_flag = sent_flag
+
     def computeTFIDF(self, docs):
         vectorizer = TfidfVectorizer(max_features=200, stop_words=stopwords.words('english'),
                                      token_pattern=r'(?u)\b[A-Za-z]+\b')
@@ -92,6 +104,9 @@ class EmoTFIDF:
         self.get_ifidf_for_words()
         em_percent = {'fear': 0.0, 'anger': 0.0, 'anticipation': 0.0, 'trust': 0.0, 'surprise': 0.0, 'positive': 0.0,
                       'negative': 0.0, 'sadness': 0.0, 'disgust': 0.0, 'joy': 0.0}
+        if self.sent_flag == 1:
+            em_percent = {'fear': 0.0, 'anger': 0.0, 'anticipation': 0.0, 'trust': 0.0, 'surprise': 0.0, 'sadness': 0.0,
+                          'disgust': 0.0, 'joy': 0.0}
         em_frequencies = Counter()
         for word in self.em_list:
             em_frequencies[word] += 1
